==> catocli-2.1.6.tar.gz: catocli-2.1.6/catocli/parsers/query_socketPortMetrics/__init__.py <==

from ..customParserApiClient import createRequest, get_help

def query_socketPortMetrics_parse(query_subparsers):
    query_socketPortMetrics_parser = query_subparsers.add_parser('socketPortMetrics', 
            help='socketPortMetrics() query operation', 
            usage=get_help("query_socketPortMetrics"))

    query_socketPortMetrics_parser.add_argument('json', nargs='?', default='{}', help='Variables in JSON format (defaults to empty object if not provided).')
    query_socketPortMetrics_parser.add_argument('-accountID', help='The cato account ID to use for this operation. Overrides the account_id value in the profile setting.  This is use for reseller and MSP accounts to run queries against cato sub accounts from the parent account.')
    query_socketPortMetrics_parser.add_argument('-t', const=True, default=False, nargs='?', help='Print GraphQL query without sending API call')
    query_socketPortMetrics_parser.add_argument('-v', const=True, default=False, nargs='?', help='Verbose output')
    query_socketPortMetrics_parser.add_argument('-p', const=True, default=False, nargs='?', help='Pretty print')
    query_socketPortMetrics_parser.add_argument('-n', '--stream-events', dest='stream_events', help='Send events over network to host:port TCP')
    query_socketPortMetrics_parser.add_argument('-z', '--sentinel', dest='sentinel', help='Send events to Sentinel customerid:sharedkey')
    query_socketPortMetrics_parser.add_argument('-H', '--header', action='append', dest='headers', help='Add custom headers in "Key: Value" format. Can be used multiple times.')
    query_socketPortMetrics_parser.add_argument('--headers-file', dest='headers_file', help='Load headers from a file. Each line should contain a header in "Key: Value" format.')
    query_socketPortMetrics_parser.set_defaults(func=createRequest,operation_name='query.socketPortMetrics')

==> catocli-3.0.36.tar.gz: catocli-3.0.36/catocli/parsers/query_socketPortMetrics/__init__.py <==

from ..customParserApiClient import createRequest, get_help
from ...Utils.help_formatter import CustomSubparserHelpFormatter

def query_socketPortMetrics_parse(query_subparsers):
    query_socketPortMetrics_parser = query_subparsers.add_parser('socketPortMetrics', 
            help='socketPortMetrics() query operation', 
            usage=get_help("query_socketPortMetrics"), formatter_class=CustomSubparserHelpFormatter)

    query_socketPortMetrics_parser.add_argument('json', nargs='?', default='{}', help='Variables in JSON format (defaults to empty object if not provided).')
    query_socketPortMetrics_parser.add_argument('-accountID', help='The cato account ID to use for this operation. Overrides the account_id value in the profile setting.  This is use for reseller and MSP accounts to run queries against cato sub accounts from the parent account.')
    query_socketPortMetrics_parser.add_argument('-t', const=True, default=False, nargs='?', help='Print GraphQL query without sending API call')
    query_socketPortMetrics_parser.add_argument('-v', const=True, default=False, nargs='?', help='Verbose output')
    query_socketPortMetrics_parser.add_argument('-p', const=True, default=False, nargs='?', help='Pretty print')
    query_socketPortMetrics_parser.add_argument('-n', '--stream-events', dest='stream_events', help='Send events over network to host:port TCP')
    query_socketPortMetrics_parser.add_argument('-z', '--sentinel', dest='sentinel', help='Send events to Sentinel customerid:sharedkey')
    query_socketPortMetrics_parser.add_argument('-H', '--header', action='append', dest='headers', help='Add custom headers in "Key: Value" format. Can be used multiple times.')
    query_socketPortMetrics_parser.add_argument('--headers-file', dest='headers_file', help='Load headers from a file. Each line should contain a header in "Key: Value" format.')
    query_socketPortMetrics_parser.add_argument('--trace-id', dest='trace_id', action='store_true', help='Enable tracing and print the trace ID from the response')


    query_socketPortMetrics_parser.add_argument('-f', '--format', choices=['json', 'csv'], help='Output format (default: formatted json, use -raw for original json)')
    query_socketPortMetrics_parser.add_argument('-raw', '--raw', dest='raw_output', action='store_true', help='Return raw/original JSON format (bypasses default formatting)')
    query_socketPortMetrics_parser.add_argument('--csv-filename', dest='csv_filename', help='Override CSV file name (default: socketportmetrics.csv)')
    query_socketPortMetrics_parser.add_argument('--append-timestamp', dest='append_timestamp', action='store_true', help='Append timestamp to the CSV file name')
    query_socketPortMetrics_parser.set_defaults(func=createRequest,operation_name='query.socketPortMetrics')
